# Image optimization for Jekyll

This Jekyll plugin helps you optimize images by thumbnailing them to
the sizes you specify in templates and in the configuration for images
in posts and collections.

It uses [Libvips](https://libvips.github.io/libvips/) for performance
and low resource usage.  It'll also cache the thumbnails so it only runs
once, but it'll update the thumbnail if the source image changes (or is
`touch`ed).

The thumbnails are smartly cropped by default to point of attention, so
they're more useful than just cropping at the center, but you can change
this (see below).

It will run `jpegoptim` and `oxipng` if it can find the binaries
installed for extra optimization.

## Installation

Add this line to your site's Gemfile:

```ruby
gem 'jekyll-images'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install jekyll-images

## Usage

### Liquid templates

In your templates, you can use the `thumbnail` filter:

```html
<img src="{{ page.image.path | thumbnail: 100 }}" />

<!-- responsive images -->

<picture>
  {% for size in site.images.sizes %}
  <source srcset="{{ page.image.path | thumbnail: size }}" media="(max-width: {{ size }}px)" />
  {% endfor %}

  <img src="{{ page.image.path | thumbnail: 750 }}" />
</picture>
```

Options for this filter are in the following order:

* `width` (required), the desired width for the image

* `height`, if provided, the thumbnail will crop to this size.  If not,
  the image is scaled down proportionally to the width.

* `crop` the smart cropping algorithm.  One of `none`, `centre`,
  `entropy` or `attention` (default).  See
  [Vips::Interesting](https://www.rubydoc.info/gems/ruby-vips/Vips/Interesting)
  for documentation.

* `auto_rotate`, a boolean (defaults to `true`).  If the image has
  orientation metadata, this controls if it's automatically rotated.

If you want to pass `crop` and `auto_rotate` but not `height`, just set
`height` to `0` or `''`.

### Configuration and posts

Images in a post content need to be configured globally:

```yaml
# _config.yml
images:
  # These are bootstrap4 breakpoints in pixels
  sizes:
    - 576
    - 768
    - 992
    - 1200
  thumbnail:
    width: 600
    height: 0 # Leave this out for proportional thumbnailing
    crop: attention # See Vips::Interesting
    auto_rotate: true
```

## TODO

* Use `<picture>` and the `srcset` attribute automatically for posts
  <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/picture>

## Contributing

Bug reports and pull requests are welcome on GitHub at
<https://0xacab.org/sutty/jekyll/jekyll-images>. This project is
intended to be a welcoming space for collaboration, and contributors are
expected to adhere to the [Sutty code of
conduct](https://sutty.nl/en/code-of-conduct/).

## License

The gem is available as free software under the terms of the GPL3
License.

## Code of Conduct

Everyone interacting in the jekyll-images project’s codebases, issue
trackers, chat rooms and mailing lists is expected to follow the [code
of conduct](https://sutty.nl/en/code-of-conduct/).
