# frozen_string_literal: true

module Jekyll
  module Filters
    # Liquid filter for use in templates
    module Thumbnail
      # Generates a thumbnail and returns its alternate destination
      def thumbnail(input, width, height = nil, crop = :attention, auto_rotate = true)
        return unless input

        height = height if height.to_i > 1
        image = Jekyll::Images::Thumbnail.new(@context.registers[:site],
                                              input,
                                              width: width,
                                              height: height,
                                              crop: crop,
                                              auto_rotate: auto_rotate)

        # XXX: This won't run optimizations more than once but it won't
        # also optimize source images.
        image.write && image.optimize
        image.dest
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::Thumbnail)
